@@ -3,8 +3,8 @@
 // Description: This file is part of FET
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
-// Copyright (C) 2005 Liviu Lalescu <http://lalescu.ro/liviu/>
+// Author: Liviu Lalescu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2005 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
  *                                                                         *
@@ -92,5 +92,7 @@ QString Building::getDetailedDescriptionWithConstraints(Rules& r)
 
 int buildingsAscending (const Building* b1, const Building* b2)
 {
-	return b1->name < b2->name;
+//	return b1->name < b2->name;
+	//by rodolforg
+	return b1->name.localeAwareCompare(b2->name)<0;
 }
