@@ -3,8 +3,8 @@
 // Description: This file is part of FET
 //
 //
-// Author: Liviu Lalescu <Please see http://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
-// Copyright (C) 2003 Liviu Lalescu <http://lalescu.ro/liviu/>
+// Author: Liviu Lalescu <Please see https://lalescu.ro/liviu/ for details about contacting Liviu Lalescu (in particular, you can find here the e-mail address)>
+// Copyright (C) 2003 Liviu Lalescu <https://lalescu.ro/liviu/>
 //
 /***************************************************************************
  *                                                                         *
@@ -128,5 +128,7 @@ QString Room::getDetailedDescriptionWithConstraints(Rules& r)
 
 int roomsAscending(const Room* r1, const Room* r2)
 {
-	return r1->name < r2->name;
+//	return r1->name < r2->name;
+	//by rodolforg
+	return r1->name.localeAwareCompare(r2->name)<0;
 }
