@@ -19,7 +19,7 @@ File solution.cpp
  *                                                                         *
  ***************************************************************************/
 
-//Teachers free periods code contributed by Volker Dirr (http://timetabling.de/)
+//Teachers free periods code contributed by Volker Dirr (https://timetabling.de/)
 
 #include <QFile>
 #include <QTextStream>
@@ -142,7 +142,7 @@ double Solution::fitness(Rules& r, QString* conflictsString){
 	}
 		
 	this->conflictsTotal=0;
-	foreach(double cn, conflictsWeightList){
+	for(double cn : qAsConst(conflictsWeightList)){
 		//cout<<"cn=="<<cn<<endl;
 		conflictsTotal+=cn;
 	}
@@ -251,8 +251,8 @@ int Solution::getSubgroupsMatrix(Rules& r, Matrix3D<int>& a){
 	return conflicts;
 }
 
-//The following 2 functions (GetTeachersTimetable & GetSubgroupsTimetable)
-//are very similar to the above 2 ones (GetTeachersMatrix & GetSubgroupsMatrix)
+//The following 2 functions (getTeachersTimetable & getSubgroupsTimetable)
+//are very similar to the above 2 ones (getTeachersMatrix & getSubgroupsMatrix)
 void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<int> >& b){
 	assert(r.initialized);
 	assert(r.internalStructureComputed);
@@ -283,7 +283,7 @@ void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<i
 		}
 
 	//Prepare teachers free periods timetable.
-	//Code contributed by Volker Dirr (http://timetabling.de/) BEGIN
+	//Code contributed by Volker Dirr (https://timetabling.de/) BEGIN
 	int d,h,tch;
 	for(d=0; d<r.nDaysPerWeek; d++){
 		for(h=0; h<r.nHoursPerDay; h++){
@@ -362,7 +362,7 @@ void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<i
 			}
 		}
 	}
-	//END of Code contributed by Volker Dirr (http://timetabling.de/) END
+	//END of Code contributed by Volker Dirr (https://timetabling.de/) END
 	//bool visited[MAX_TEACHERS];
 	Matrix1D<bool> visited;
 	visited.resize(r.nInternalTeachers);
@@ -371,7 +371,7 @@ void Solution::getTeachersTimetable(Rules& r, Matrix3D<int>& a, Matrix3D<QList<i
 			for(tch=0; tch<r.nInternalTeachers; tch++)
 				visited[tch]=false;
 			for(int tfp=0; tfp<TEACHERS_FREE_PERIODS_N_CATEGORIES; tfp++){
-				foreach(int tch, b[tfp][d][h]){
+				for(int tch : qAsConst(b[tfp][d][h])){
 					assert(!visited[tch]);
 					visited[tch]=true;
 				}
@@ -411,7 +411,7 @@ void Solution::getSubgroupsTimetable(Rules& r, Matrix3D<int>& a){
 }
 
 int Solution::getRoomsMatrix(
-	Rules& r, 
+	Rules& r,
 	Matrix3D<int>& a)
 {
 	assert(r.initialized);
