@@ -33,6 +33,19 @@ File timetable_defs.h
 
 #include "centerwidgetonscreen.h"
 
+#if QT_VERSION < 0x050700
+#include <type_traits>
+namespace std
+{
+	template<class T> using add_const_t = typename add_const<T>::type;
+}
+template<class T> constexpr std::add_const_t<T>& qAsConst(T& t) noexcept
+{
+	return t;
+}
+template<class T> void qAsConst(const T&&) = delete;
+#endif
+
 class QWidget;
 
 /**
@@ -304,6 +317,11 @@ extern bool checkForUpdates;
 
 extern QString internetVersion;
 
+const int STUDENTS_COMBO_BOXES_STYLE_SIMPLE=0;
+const int STUDENTS_COMBO_BOXES_STYLE_ICONS=1;
+const int STUDENTS_COMBO_BOXES_STYLE_CATEGORIZED=2;
+extern int STUDENTS_COMBO_BOXES_STYLE;
+
 ///////tricks to save work to reconvert old code
 const int CUSTOM_DOUBLE_PRECISION=6; //number of digits after the decimal dot for the weights
 
