@@ -80,7 +80,8 @@ AddConstraintActivityPreferredRoomForm::AddConstraintActivityPreferredRoomForm(Q
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -92,7 +93,7 @@ AddConstraintActivityPreferredRoomForm::AddConstraintActivityPreferredRoomForm(Q
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 	
 	updateActivitiesComboBox();
