@@ -51,7 +51,8 @@ AddConstraintStudentsSetMaxHoursDailyForm::~AddConstraintStudentsSetMaxHoursDail
 
 void AddConstraintStudentsSetMaxHoursDailyForm::updateStudentsSetComboBox()
 {
-	studentsComboBox->clear();	
+	populateStudentsComboBox(studentsComboBox);
+	/*studentsComboBox->clear();
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -63,7 +64,7 @@ void AddConstraintStudentsSetMaxHoursDailyForm::updateStudentsSetComboBox()
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 
 	constraintChanged();
 }
