@@ -52,7 +52,7 @@ AddConstraintTeacherMinGapsBetweenBuildingChangesForm::~AddConstraintTeacherMinG
 void AddConstraintTeacherMinGapsBetweenBuildingChangesForm::updateTeachersComboBox()
 {
 	teachersComboBox->clear();
-	foreach(Teacher* tch, gt.rules.teachersList)
+	for(Teacher* tch : qAsConst(gt.rules.teachersList))
 		teachersComboBox->addItem(tch->name);
 
 	constraintChanged();
