@@ -7,7 +7,7 @@
                           advancedlockunlockform.h  -  description
                              -------------------
     begin                : Dec 2008
-    copyright            : (C) by Liviu Lalescu (https://lalescu.ro/liviu/) and Volker Dirr (http://www.timetabling.de/)
+    copyright            : (C) by Liviu Lalescu (https://lalescu.ro/liviu/) and Volker Dirr (https://www.timetabling.de/)
  ***************************************************************************
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
@@ -38,6 +38,11 @@ public:
 	
 	static void lockEndStudentsDay(QWidget* parent);
 	static void unlockEndStudentsDay(QWidget* parent);
+	
+	static void lockActivityTag(QWidget* parent);
+	static void unlockActivityTag(QWidget* parent);
+
+	static void unlockActivityTagWithoutTimetable(QWidget* parent);
 };
 
 #endif
