@@ -85,7 +85,8 @@ ConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::ConstraintActivitiesOcc
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -97,7 +98,7 @@ ConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::ConstraintActivitiesOcc
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
@@ -129,7 +130,7 @@ bool ConstraintActivitiesOccupyMaxTimeSlotsFromSelectionForm::filterOk(TimeConst
 	for(int i=0; i<c->activitiesIds.count(); i++){
 		int id=c->activitiesIds.at(i);
 		Activity* act=NULL;
-		foreach(Activity* a, gt.rules.activitiesList)
+		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
 				act=a;
 		
