@@ -94,7 +94,8 @@ ConstraintActivityPreferredRoomForm::ConstraintActivityPreferredRoomForm(QWidget
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -106,7 +107,7 @@ ConstraintActivityPreferredRoomForm::ConstraintActivityPreferredRoomForm(QWidget
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
@@ -134,7 +135,7 @@ bool ConstraintActivityPreferredRoomForm::filterOk(SpaceConstraint* ctr)
 	
 	int id=c->activityId;
 	Activity* act=NULL;
-	foreach(Activity* a, gt.rules.activitiesList)
+	for(Activity* a : qAsConst(gt.rules.activitiesList))
 		if(a->id==id)
 			act=a;
 
