@@ -63,7 +63,7 @@ ConstraintTeacherActivityTagMaxHoursDailyForm::ConstraintTeacherActivityTagMaxHo
 	
 	activityTagsComboBox->clear();
 	activityTagsComboBox->addItem("");
-	foreach(ActivityTag* at, gt.rules.activityTagsList)
+	for(ActivityTag* at : qAsConst(gt.rules.activityTagsList))
 		activityTagsComboBox->addItem(at->name);
 
 	this->filterChanged();
