@@ -83,7 +83,8 @@ ConstraintTwoActivitiesConsecutiveForm::ConstraintTwoActivitiesConsecutiveForm(Q
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -95,7 +96,7 @@ ConstraintTwoActivitiesConsecutiveForm::ConstraintTwoActivitiesConsecutiveForm(Q
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 ///////////////
 
@@ -137,7 +138,7 @@ bool ConstraintTwoActivitiesConsecutiveForm::filterOk(TimeConstraint* ctr)
 		assert(id>=0);
 
 		Activity* act=NULL;
-		foreach(Activity* a, gt.rules.activitiesList)
+		for(Activity* a : qAsConst(gt.rules.activitiesList))
 			if(a->id==id)
 				act=a;
 		
