@@ -154,14 +154,17 @@ public slots:
 	void on_dataTeachersSubjectsQualificationsStatisticsAction_triggered();
 	void on_dataHelpOnStatisticsAction_triggered();
 	
+	void checkForUpdatesToggled(bool checked);
 	void on_helpSettingsAction_triggered();
-	void on_settingsUseColorsAction_toggled();
+	void useColorsToggled(bool checked);
 	void showSubgroupsInComboBoxesToggled(bool checked);
 	void showSubgroupsInActivityPlanningToggled(bool checked);
 	void on_settingsShowShortcutsOnMainWindowAction_toggled();
 	void on_settingsShowToolTipsForConstraintsWithTablesAction_toggled();
 	
 	void on_timetablesToWriteOnDiskAction_triggered();
+	
+	void on_studentsComboBoxesStyleAction_triggered();
 	///
 
 	//////confirmations
@@ -235,6 +238,7 @@ public slots:
 	void on_dataTimeConstraintsTwoActivitiesGroupedAction_triggered();
 	void on_dataTimeConstraintsThreeActivitiesGroupedAction_triggered();
 	void on_dataTimeConstraintsTwoActivitiesOrderedAction_triggered();
+	void on_dataTimeConstraintsTwoActivitiesOrderedIfSameDayAction_triggered();
 	void on_dataTimeConstraintsActivityPreferredStartingTimeAction_triggered();
 	void on_dataTimeConstraintsActivityPreferredTimeSlotsAction_triggered();
 	void on_dataTimeConstraintsActivitiesPreferredTimeSlotsAction_triggered();
@@ -353,6 +357,8 @@ public slots:
 	void on_timetableUnlockActivitiesDayAction_triggered();
 	void on_timetableLockActivitiesEndStudentsDayAction_triggered();
 	void on_timetableUnlockActivitiesEndStudentsDayAction_triggered();
+	void on_timetableLockActivitiesWithASpecifiedActivityTagAction_triggered();
+	void on_timetableUnlockActivitiesWithASpecifiedActivityTagAction_triggered();
 
 	void on_timetableSaveTimetableAsAction_triggered();
 
@@ -360,8 +366,6 @@ public slots:
 	
 	void on_languageAction_triggered();
 	
-	void on_checkForUpdatesAction_toggled();
-	
 	void on_settingsDivideTimetablesByDaysAction_toggled();
 	void on_settingsDuplicateVerticalNamesAction_toggled();
 
