@@ -81,7 +81,8 @@ ModifyConstraintActivityPreferredStartingTimeForm::ModifyConstraintActivityPrefe
 	}
 	activityTagsComboBox->setCurrentIndex(0);
 
-	studentsComboBox->addItem("");
+	populateStudentsComboBox(studentsComboBox, QString(""), true);
+	/*studentsComboBox->addItem("");
 	for(int i=0; i<gt.rules.yearsList.size(); i++){
 		StudentsYear* sty=gt.rules.yearsList[i];
 		studentsComboBox->addItem(sty->name);
@@ -93,7 +94,7 @@ ModifyConstraintActivityPreferredStartingTimeForm::ModifyConstraintActivityPrefe
 				studentsComboBox->addItem(sts->name);
 			}
 		}
-	}
+	}*/
 	studentsComboBox->setCurrentIndex(0);
 	
 	updatePeriodGroupBox();
@@ -249,7 +250,7 @@ void ModifyConstraintActivityPreferredStartingTimeForm::ok()
 		
 		bool duplicate=false;
 		
-		foreach(TimeConstraint* tc, gt.rules.timeConstraintsList)
+		for(TimeConstraint* tc : qAsConst(gt.rules.timeConstraintsList))
 			if(tc!=this->_ctr && tc->type==CONSTRAINT_ACTIVITY_PREFERRED_STARTING_TIME)
 				if( ( *((ConstraintActivityPreferredStartingTime*)tc) ) == apst){
 					duplicate=true;
