@@ -34,7 +34,6 @@ ModifyConstraintStudentsSetMaxSpanPerDayForm::ModifyConstraintStudentsSetMaxSpan
 
 	QSize tmp2=studentsComboBox->minimumSizeHint();
 	Q_UNUSED(tmp2);
-
 	
 	this->_ctr=ctr;
 	
@@ -55,7 +54,8 @@ ModifyConstraintStudentsSetMaxSpanPerDayForm::~ModifyConstraintStudentsSetMaxSpa
 }
 
 void ModifyConstraintStudentsSetMaxSpanPerDayForm::updateStudentsComboBox(QWidget* parent){
-	studentsComboBox->clear();
+	int j=populateStudentsComboBox(studentsComboBox, this->_ctr->students);
+	/*studentsComboBox->clear();
 	int i=0, j=-1;
 	for(int m=0; m<gt.rules.yearsList.size(); m++){
 		StudentsYear* sty=gt.rules.yearsList[m];
@@ -77,7 +77,7 @@ void ModifyConstraintStudentsSetMaxSpanPerDayForm::updateStudentsComboBox(QWidge
 				i++;
 			}
 		}
-	}
+	}*/
 	if(j<0)
 		showWarningForInvisibleSubgroupConstraint(parent, this->_ctr->students);
 	else
