@@ -36,6 +36,16 @@ ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ModifyConstraintSubactiviti
 {
 	setupUi(this);
 
+	int duration=ctr->duration;
+	durationCheckBox->setChecked(duration>=1);
+	durationSpinBox->setEnabled(duration>=1);
+	durationSpinBox->setMinimum(1);
+	durationSpinBox->setMaximum(gt.rules.nHoursPerDay);
+	if(duration>=1)
+		durationSpinBox->setValue(duration);
+	else
+		durationSpinBox->setValue(1);
+
 	okPushButton->setDefault(true);
 
 	connect(preferredTimesTable, SIGNAL(itemClicked(QTableWidgetItem*)), this, SLOT(itemClicked(QTableWidgetItem*)));
@@ -233,7 +243,8 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::updateTeachersComboBox
 }
 
 void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::updateStudentsComboBox(QWidget* parent){
-	int i=0, j=-1;
+	int j=populateStudentsComboBox(studentsComboBox, this->_ctr->p_studentsName, true);
+	/*int i=0, j=-1;
 	studentsComboBox->clear();
 	studentsComboBox->addItem("");
 	if(this->_ctr->p_studentsName=="")
@@ -259,7 +270,7 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::updateStudentsComboBox
 				i++;
 			}
 		}
-	}
+	}*/
 	if(j<0)
 		showWarningForInvisibleSubgroupConstraint(parent, this->_ctr->p_studentsName);
 	else
@@ -305,6 +316,12 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::updateActivityTagsComb
 
 void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ok()
 {
+	int duration=-1;
+	if(durationCheckBox->isChecked()){
+		assert(durationSpinBox->isEnabled());
+		duration=durationSpinBox->value();
+	}
+
 	if(studentsComboBox->currentIndex()<0){
 		showWarningCannotModifyConstraintInvisibleSubgroupConstraint(this, this->_ctr->p_studentsName);
 		return;
@@ -369,6 +386,8 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::ok()
 	this->_ctr->p_days_L=days_L;
 	this->_ctr->p_hours_L=hours_L;
 
+	this->_ctr->duration=duration;
+
 	gt.rules.internalStructureComputed=false;
 	setRulesModifiedAndOtherThings(&gt.rules);
 	
@@ -380,5 +399,10 @@ void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::cancel()
 	this->close();
 }
 
+void ModifyConstraintSubactivitiesPreferredTimeSlotsForm::on_durationCheckBox_toggled()
+{
+	durationSpinBox->setEnabled(durationCheckBox->isChecked());
+}
+
 #undef YES
 #undef NO
