@@ -2,13 +2,13 @@
                                 FET
                           -------------------
    copyright             : (C) by Liviu Lalescu, Volker Dirr
-    email                : Liviu Lalescu: see https://lalescu.ro/liviu/ , Volker Dirr: see http://www.timetabling.de/
+    email                : Liviu Lalescu: see https://lalescu.ro/liviu/ , Volker Dirr: see https://www.timetabling.de/
  ***************************************************************************
                           statisticsprintform.cpp  -  description
                              -------------------
     begin                : November 2013
     copyright            : (C) by Volker Dirr
-                         : http://www.timetabling.de/
+                         : https://www.timetabling.de/
  ***************************************************************************
  *                                                                         *
  *   This program is free software: you can redistribute it and/or modify  *
@@ -227,7 +227,7 @@ StatisticsPrintForm::StatisticsPrintForm(QWidget *parent): QDialog(parent){
 	
 	//CBpaperSize->addItems(paperSizesMap.keys());
 	QList<LocaleString> items=paperSizesMap.keys();
-	foreach(LocaleString s, items)
+	for(const LocaleString& s : qAsConst(items))
 		CBpaperSize->addItem(s);
 	
 	if(CBpaperSize->count()>=5)
@@ -607,31 +607,31 @@ void StatisticsPrintForm::updateNamesList(){
 	
 	if(studentSubjectRB->isChecked() || studentTeacherRB->isChecked()){
 		int count=0;
-		foreach(QString student, statisticValues.allStudentsNames){
+		for(const QString& student : qAsConst(statisticValues.allStudentsNames)){
 			namesList->addItem(student);
 			QListWidgetItem* tmpItem=namesList->item(count);
 			tmpItem->setSelected(true);
 			count++;
-		}	
+		}
 	}
 	if(teacherSubjectRB->isChecked() || teacherStudentRB->isChecked()){
 		int count=0;
-		foreach(QString teacher, statisticValues.allTeachersNames){
+		for(const QString& teacher : qAsConst(statisticValues.allTeachersNames)){
 			namesList->addItem(teacher);
 			QListWidgetItem* tmpItem=namesList->item(count);
 			tmpItem->setSelected(true);
 			count++;
-		}	
+		}
 	}
 	if(subjectStudentRB->isChecked() || subjectTeacherRB->isChecked()){
 	int count=0;
-		foreach(QString subject, statisticValues.allSubjectsNames){
+		for(const QString& subject : qAsConst(statisticValues.allSubjectsNames)){
 			namesList->addItem(subject);
 			QListWidgetItem* tmpItem=namesList->item(count);
 			tmpItem->setSelected(true);
 			count++;
-		}	
-	}	
+		}
+	}
 }
 
 QString StatisticsPrintForm::updateHTMLprintString(bool printAll){
