@@ -135,6 +135,8 @@ TimetableGenerateForm::~TimetableGenerateForm()
 }
 
 void TimetableGenerateForm::start(){
+	//closeAllTimetableViewDialogs();
+
 	if(!gt.rules.internalStructureComputed){
 		if(!gt.rules.computeInternalStructure(this)){
 			QMessageBox::warning(this, TimetableGenerateForm::tr("FET warning"), TimetableGenerateForm::tr("Data is wrong. Please correct and try again"));
@@ -219,8 +221,10 @@ void TimetableGenerateForm::stop()
 	conflictsString+=TimetableGenerateForm::tr("Conflicts listing (in decreasing order):");
 	conflictsString+="\n";
 
-	foreach(QString t, c.conflictsDescriptionList)
+	for(const QString& t : qAsConst(c.conflictsDescriptionList))
 		conflictsString+=t+"\n";
+	
+	updateAllTimetableViewDialogs();
 
 	TimetableExport::writeSimulationResults(this);
 
@@ -372,9 +376,11 @@ void TimetableGenerateForm::stopHighest()
 	conflictsString+=TimetableGenerateForm::tr("Conflicts listing (in decreasing order):");
 	conflictsString+="\n";
 
-	foreach(QString t, c.conflictsDescriptionList)
+	for(const QString& t : qAsConst(c.conflictsDescriptionList))
 		conflictsString+=t+"\n";
 
+	updateAllTimetableViewDialogs();
+
 	TimetableExport::writeHighestStageResults(this);
 
 	QString s=TimetableGenerateForm::tr("Simulation interrupted! FET could not find a timetable."
@@ -503,11 +509,12 @@ void TimetableGenerateForm::impossibleToSolve()
 	conflictsString+=TimetableGenerateForm::tr("Conflicts listing (in decreasing order):");
 	conflictsString+="\n";
 
-	foreach(QString t, c.conflictsDescriptionList)
+	for(const QString& t : qAsConst(c.conflictsDescriptionList))
 		conflictsString+=t+"\n";
 
-	TimetableExport::writeSimulationResults(this);
+	updateAllTimetableViewDialogs();
 
+	TimetableExport::writeSimulationResults(this);
 
 	QString s=TimetableGenerateForm::tr("Simulation impossible! Maybe you can consider lowering the constraints.");
 
@@ -629,9 +636,11 @@ void TimetableGenerateForm::simulationFinished()
 	conflictsString+=TimetableGenerateForm::tr("Soft conflicts listing (in decreasing order):");
 	conflictsString+="\n";
 
-	foreach(QString t, c.conflictsDescriptionList)
+	for(const QString& t : qAsConst(c.conflictsDescriptionList))
 		conflictsString+=t+"\n";
 
+	updateAllTimetableViewDialogs();
+
 	TimetableExport::writeSimulationResults(this);
 
 	QString kk;
@@ -809,9 +818,11 @@ void TimetableGenerateForm::write(){
 	conflictsString+=TimetableGenerateForm::tr("Conflicts listing (in decreasing order):");
 	conflictsString+="\n";
 
-	foreach(QString t, c.conflictsDescriptionList)
+	for(const QString& t : qAsConst(c.conflictsDescriptionList))
 		conflictsString+=t+"\n";
 
+	updateAllTimetableViewDialogs();
+
 	TimetableExport::writeSimulationResults(this);
 
 	myMutex.unlock();
@@ -858,9 +869,11 @@ void TimetableGenerateForm::writeHighestStage(){
 	conflictsString+=TimetableGenerateForm::tr("Conflicts listing (in decreasing order):");
 	conflictsString+="\n";
 
-	foreach(QString t, c.conflictsDescriptionList)
+	for(const QString& t : qAsConst(c.conflictsDescriptionList))
 		conflictsString+=t+"\n";
 
+	updateAllTimetableViewDialogs();
+
 	TimetableExport::writeHighestStageResults(this);
 
 	myMutex.unlock();
