@@ -248,6 +248,8 @@ void TimetableGenerateMultipleForm::help()
 }
 
 void TimetableGenerateMultipleForm::start(){
+	//closeAllTimetableViewDialogs();
+
 	nTimetables=timetablesSpinBox->value();
 	assert(nTimetables>0);
 	timeLimit=60*minutesSpinBox->value(); //seconds
@@ -359,8 +361,10 @@ void TimetableGenerateMultipleForm::timetableGenerated(int timetable, const QStr
 		conflictsString+="\n";
 		conflictsString += tr("Soft conflicts listing (in decreasing order):")+"\n";
 
-		foreach(QString t, best_solution.conflictsDescriptionList)
+		for(const QString& t : qAsConst(best_solution.conflictsDescriptionList))
 			conflictsString+=t+"\n";
+		
+		updateAllTimetableViewDialogs();
 	}
 
 	semaphoreTimetableFinished.release();
