@@ -33,6 +33,7 @@
 #include "lockunlock.h"
 
 #include <QList>
+#include <QSet>
 
 #include <QMessageBox>
 
@@ -102,7 +103,8 @@ TimetableViewStudentsDaysHorizontalForm::TimetableViewStudentsDaysHorizontalForm
 	groupsListWidget->clear();
 	subgroupsListWidget->clear();
 	
-	connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+	//This connect should be lower in the code
+	//connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
 	connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
 	connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
 	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
@@ -151,7 +153,8 @@ TimetableViewStudentsDaysHorizontalForm::TimetableViewStudentsDaysHorizontalForm
 	assert(backupPermanentlyLockedSpace==idsOfPermanentlyLockedSpace);
 //////////
 
-	LockUnlock::increaseCommunicationSpinBox();
+	//Commented on 2018-07-20
+	//LockUnlock::increaseCommunicationSpinBox();
 
 	studentsTimetableTable->setRowCount(gt.rules.nHoursPerDay);
 	studentsTimetableTable->setColumnCount(gt.rules.nDaysPerWeek);
@@ -195,9 +198,173 @@ TimetableViewStudentsDaysHorizontalForm::TimetableViewStudentsDaysHorizontalForm
 	}
 	if(yearsListWidget->count()>0)
 		yearsListWidget->setCurrentRow(0);
+	connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+		
+	shownComboBox->addItem(tr("Years"));
+	shownComboBox->addItem(tr("Groups"));
+	shownComboBox->addItem(tr("Subgroups"));
+
+	shownComboBox->setCurrentIndex(-1);
+
+	if(settings.contains(this->metaObject()->className()+QString("/shown-categories")))
+		shownComboBox->setCurrentIndex(settings.value(this->metaObject()->className()+QString("/shown-categories")).toInt());
+	else
+		shownComboBox->setCurrentIndex(0);
+
+	connect(shownComboBox, SIGNAL(activated(QString)), this, SLOT(shownComboBoxChanged(QString)));
 
 	//added by Volker Dirr
 	connect(&communicationSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateStudentsTimetableTable()));
+
+	shownComboBoxChanged(shownComboBox->currentText());
+}
+
+void TimetableViewStudentsDaysHorizontalForm::newTimetableGenerated()
+{
+	/*setupUi(this);
+	
+	closePushButton->setDefault(true);
+	
+	detailsTextEdit->setReadOnly(true);
+
+	//columnResizeModeInitialized=false;
+
+	verticalStudentsTableDetailsSplitter->setStretchFactor(0, 4);
+	verticalStudentsTableDetailsSplitter->setStretchFactor(1, 1);
+	horizontalSplitter->setStretchFactor(0, 3);
+	horizontalSplitter->setStretchFactor(1, 10);
+	
+	studentsTimetableTable->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	
+	yearsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+	groupsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);
+	subgroupsListWidget->setSelectionMode(QAbstractItemView::SingleSelection);*/
+
+	disconnect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+	disconnect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+	groupsListWidget->clear();
+	subgroupsListWidget->clear();
+	connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+	connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+	
+	//This connect should be lower in the code
+	//connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+	/*connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+	connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(studentsTimetableTable, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), this, SLOT(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)));
+	connect(lockTimePushButton, SIGNAL(clicked()), this, SLOT(lockTime()));
+	connect(lockSpacePushButton, SIGNAL(clicked()), this, SLOT(lockSpace()));
+	connect(lockTimeSpacePushButton, SIGNAL(clicked()), this, SLOT(lockTimeSpace()));
+	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));
+
+	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
+
+	//restore vertical students list splitter state
+	QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/vertical-students-list-splitter-state")))
+		verticalStudentsListSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/vertical-students-list-splitter-state")).toByteArray());
+
+	//restore vertical students table details splitter state
+	//QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/vertical-students-table-details-splitter-state")))
+		verticalStudentsTableDetailsSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/vertical-students-table-details-splitter-state")).toByteArray());
+
+	//restore horizontal splitter state
+	//QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/horizontal-splitter-state")))
+		horizontalSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/horizontal-splitter-state")).toByteArray());*/
+
+//////////just for testing
+	QSet<int> backupLockedTime;
+	QSet<int> backupPermanentlyLockedTime;
+	QSet<int> backupLockedSpace;
+	QSet<int> backupPermanentlyLockedSpace;
+
+	backupLockedTime=idsOfLockedTime;
+	backupPermanentlyLockedTime=idsOfPermanentlyLockedTime;
+	backupLockedSpace=idsOfLockedSpace;
+	backupPermanentlyLockedSpace=idsOfPermanentlyLockedSpace;
+
+	//added by Volker Dirr
+	//these lines are not really needed - just to be safer
+	LockUnlock::computeLockedUnlockedActivitiesTimeSpace();
+	
+	assert(backupLockedTime==idsOfLockedTime);
+	assert(backupPermanentlyLockedTime==idsOfPermanentlyLockedTime);
+	assert(backupLockedSpace==idsOfLockedSpace);
+	assert(backupPermanentlyLockedSpace==idsOfPermanentlyLockedSpace);
+//////////
+
+	//DON'T UNCOMMENT THIS CODE -> LEADS TO CRASH IF THERE ARE MORE VIEWS OPENED.
+	//LockUnlock::increaseCommunicationSpinBox();
+
+	studentsTimetableTable->clear();
+	studentsTimetableTable->setRowCount(gt.rules.nHoursPerDay);
+	studentsTimetableTable->setColumnCount(gt.rules.nDaysPerWeek);
+	for(int j=0; j<gt.rules.nDaysPerWeek; j++){
+		QTableWidgetItem* item=new QTableWidgetItem(gt.rules.daysOfTheWeek[j]);
+		studentsTimetableTable->setHorizontalHeaderItem(j, item);
+	}
+	for(int i=0; i<gt.rules.nHoursPerDay; i++){
+		QTableWidgetItem* item=new QTableWidgetItem(gt.rules.hoursOfTheDay[i]);
+		studentsTimetableTable->setVerticalHeaderItem(i, item);
+	}
+	for(int j=0; j<gt.rules.nHoursPerDay; j++){
+		for(int k=0; k<gt.rules.nDaysPerWeek; k++){
+			QTableWidgetItem* item= new QTableWidgetItem();
+			item->setTextAlignment(Qt::AlignCenter);
+			item->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEnabled);
+
+			studentsTimetableTable->setItem(j, k, item);
+
+			//if(j==0 && k==0)
+			//	teachersTimetableTable->setCurrentItem(item);
+		}
+	}
+	
+	//resize columns
+	//if(!columnResizeModeInitialized){
+/*	studentsTimetableTable->horizontalHeader()->setMinimumSectionSize(studentsTimetableTable->horizontalHeader()->defaultSectionSize());
+	//	columnResizeModeInitialized=true;
+#if QT_VERSION >= 0x050000
+	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Stretch);
+#else
+	studentsTimetableTable->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
+#endif
+	//}
+	///////////////
+*/
+	
+	disconnect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+	yearsListWidget->clear();
+	for(int i=0; i<gt.rules.augmentedYearsList.size(); i++){
+		StudentsYear* sty=gt.rules.augmentedYearsList[i];
+		yearsListWidget->addItem(sty->name);
+	}
+	if(yearsListWidget->count()>0)
+		yearsListWidget->setCurrentRow(0);
+	connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+		
+/*	shownComboBox->addItem(tr("Years"));
+	shownComboBox->addItem(tr("Groups"));
+	shownComboBox->addItem(tr("Subgroups"));
+
+	shownComboBox->setCurrentIndex(-1);
+
+	if(settings.contains(this->metaObject()->className()+QString("/shown-categories")))
+		shownComboBox->setCurrentIndex(settings.value(this->metaObject()->className()+QString("/shown-categories")).toInt());
+	else
+		shownComboBox->setCurrentIndex(0);
+
+	connect(shownComboBox, SIGNAL(activated(QString)), this, SLOT(shownComboBoxChanged(QString)));
+*/
+
+	//added by Volker Dirr
+	//connect(&communicationSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateStudentsTimetableTable()));
+
+	shownComboBoxChanged(shownComboBox->currentText());
 }
 
 TimetableViewStudentsDaysHorizontalForm::~TimetableViewStudentsDaysHorizontalForm()
@@ -215,6 +382,8 @@ TimetableViewStudentsDaysHorizontalForm::~TimetableViewStudentsDaysHorizontalFor
 	//save horizontal splitter state
 	//QSettings settings(COMPANY, PROGRAM);
 	settings.setValue(this->metaObject()->className()+QString("/horizontal-splitter-state"), horizontalSplitter->saveState());
+	
+	settings.setValue(this->metaObject()->className()+QString("/shown-categories"), shownComboBox->currentIndex());
 }
 
 void TimetableViewStudentsDaysHorizontalForm::resizeRowsAfterShow()
@@ -223,6 +392,80 @@ void TimetableViewStudentsDaysHorizontalForm::resizeRowsAfterShow()
 //	tableWidgetUpdateBug(studentsTimetableTable);
 }
 
+void TimetableViewStudentsDaysHorizontalForm::shownComboBoxChanged(QString shownCategory)
+{
+	Q_UNUSED(shownCategory);
+
+	if(shownComboBox->currentIndex()==0){
+		//years, groups, and subgroups shown
+		yearsListWidget->show();
+		groupsListWidget->show();
+		subgroupsListWidget->show();
+		
+		disconnect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+		yearsListWidget->clear();
+		for(int i=0; i<gt.rules.augmentedYearsList.size(); i++){
+			StudentsYear* sty=gt.rules.augmentedYearsList[i];
+			yearsListWidget->addItem(sty->name);
+		}
+		if(yearsListWidget->count()>0)
+			yearsListWidget->setCurrentRow(0);
+		connect(yearsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(yearChanged(const QString&)));
+		if(yearsListWidget->count()>0)
+			yearChanged(yearsListWidget->item(0)->text());
+	}
+	else if(shownComboBox->currentIndex()==1){
+		//only groups and subgroups shown
+		yearsListWidget->hide();
+		groupsListWidget->show();
+		subgroupsListWidget->show();
+
+		disconnect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+		groupsListWidget->clear();
+		QSet<QString> groupsSet;
+		for(int i=0; i<gt.rules.augmentedYearsList.size(); i++){
+			StudentsYear* sty=gt.rules.augmentedYearsList[i];
+			for(StudentsGroup* stg : qAsConst(sty->groupsList))
+				if(!groupsSet.contains(stg->name)){
+					groupsListWidget->addItem(stg->name);
+					groupsSet.insert(stg->name);
+				}
+		}
+		if(groupsListWidget->count()>0)
+			groupsListWidget->setCurrentRow(0);
+		connect(groupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(groupChanged(const QString&)));
+		if(groupsListWidget->count()>0)
+			groupChanged(groupsListWidget->item(0)->text());
+	}
+	else if(shownComboBox->currentIndex()==2){
+		//only subgroups shown
+		yearsListWidget->hide();
+		groupsListWidget->hide();
+		subgroupsListWidget->show();
+
+		disconnect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+		subgroupsListWidget->clear();
+		QSet<QString> subgroupsSet;
+		for(int i=0; i<gt.rules.augmentedYearsList.size(); i++){
+			StudentsYear* sty=gt.rules.augmentedYearsList[i];
+			for(StudentsGroup* stg : qAsConst(sty->groupsList))
+				for(StudentsSubgroup* sts : qAsConst(stg->subgroupsList))
+					if(!subgroupsSet.contains(sts->name)){
+						subgroupsListWidget->addItem(sts->name);
+						subgroupsSet.insert(sts->name);
+					}
+		}
+		if(subgroupsListWidget->count()>0)
+			subgroupsListWidget->setCurrentRow(0);
+		connect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
+		if(subgroupsListWidget->count()>0)
+			subgroupChanged(subgroupsListWidget->item(0)->text());
+	}
+	else{
+		assert(0);
+	}
+}
+
 void TimetableViewStudentsDaysHorizontalForm::yearChanged(const QString &yearName)
 {
 	if(!(students_schedule_ready && teachers_schedule_ready)){
@@ -264,8 +507,20 @@ void TimetableViewStudentsDaysHorizontalForm::groupChanged(const QString &groupN
 
 	if(groupName==QString())
 		return;
-
-	QString yearName=yearsListWidget->currentItem()->text();
+	
+	StudentsSet* ss=gt.rules.searchAugmentedStudentsSet(groupName);
+	if(ss==NULL){
+		QMessageBox::warning(this, tr("FET warning"), tr("Inexistent group - please reload this dialog"));
+		return;
+	}
+	if(ss->type!=STUDENTS_GROUP){
+		QMessageBox::warning(this, tr("FET warning"), tr("Incorrect group settings - please reload this dialog"));
+		return;
+	}
+	
+	StudentsGroup* stg=(StudentsGroup*)ss;
+	
+	/*QString yearName=yearsListWidget->currentItem()->text();
 	int yearIndex=gt.rules.searchAugmentedYear(yearName);
 	if(yearIndex<0){
 		QMessageBox::warning(this, tr("FET warning"), tr("Invalid year - please close this dialog and open a new students view timetable dialog"));
@@ -281,13 +536,13 @@ void TimetableViewStudentsDaysHorizontalForm::groupChanged(const QString &groupN
 		 tr("Solution: please try to select a different year and after that select the current year again, "
 		 "to refresh the groups list, or close this dialog and open again the students view timetable dialog"));
 		return;
-	}
+	}*/
 	
 	disconnect(subgroupsListWidget, SIGNAL(currentTextChanged(const QString&)), this, SLOT(subgroupChanged(const QString&)));
 
 	subgroupsListWidget->clear();
 	
-	StudentsGroup* stg=sty->groupsList.at(groupIndex);
+	//StudentsGroup* stg=sty->groupsList.at(groupIndex);
 	for(int i=0; i<stg->subgroupsList.size(); i++){
 		StudentsSubgroup* sts=stg->subgroupsList[i];
 		subgroupsListWidget->addItem(sts->name);
@@ -320,26 +575,31 @@ void TimetableViewStudentsDaysHorizontalForm::updateStudentsTimetableTable(){
 	}
 
 	QString s;
-	QString yearname;
-	QString groupname;
+	//QString yearname;
+	//QString groupname;
 	QString subgroupname;
 
-	if(yearsListWidget->currentRow()<0 || yearsListWidget->currentRow()>=yearsListWidget->count())
+	/*if(yearsListWidget->currentRow()<0 || yearsListWidget->currentRow()>=yearsListWidget->count())
 		return;
 	if(groupsListWidget->currentRow()<0 || groupsListWidget->currentRow()>=groupsListWidget->count())
 		return;
 	if(subgroupsListWidget->currentRow()<0 || subgroupsListWidget->currentRow()>=subgroupsListWidget->count())
-		return;
+		return;*/
 
-	yearname = yearsListWidget->currentItem()->text();
-	groupname = groupsListWidget->currentItem()->text();
+	//yearname = yearsListWidget->currentItem()->text();
+	//groupname = groupsListWidget->currentItem()->text();
 	subgroupname = subgroupsListWidget->currentItem()->text();
 
-	StudentsSubgroup* sts=(StudentsSubgroup*)gt.rules.searchAugmentedStudentsSet(subgroupname);
-	if(sts==NULL){
-		QMessageBox::information(this, tr("FET warning"), tr("You have an old timetable view students dialog opened - please close it"));
+	StudentsSet* ss=gt.rules.searchAugmentedStudentsSet(subgroupname);
+	if(ss==NULL){
+		QMessageBox::information(this, tr("FET warning"), tr("Inexistent subgroup - please reload this dialog"));
 		return;
 	}
+	if(ss->type!=STUDENTS_SUBGROUP){
+		QMessageBox::warning(this, tr("FET warning"), tr("Incorrect subgroup settings - please reload this dialog"));
+		return;
+	}
+	StudentsSubgroup* sts=(StudentsSubgroup*)ss;
 
 	s="";
 	s += subgroupname;
@@ -565,6 +825,12 @@ void TimetableViewStudentsDaysHorizontalForm::detailActivity(QTableWidgetItem* i
 			if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
 				s+="\n";
 				s+=tr("Room: %1").arg(gt.rules.internalRoomsList[r]->name);
+				if(gt.rules.internalRoomsList[r]->building!=""){
+					s+="\n";
+					s+=tr("Building=%1").arg(gt.rules.internalRoomsList[r]->building);
+				}
+				s+="\n";
+				s+=tr("Capacity=%1").arg(gt.rules.internalRoomsList[r]->capacity);
 			}
 			//added by Volker Dirr (start)
 			QString descr="";
@@ -710,7 +976,7 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 							tmptc.clear();
 							int count=0;
 
-							foreach(ConstraintActivityPreferredStartingTime* c, gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
+							for(ConstraintActivityPreferredStartingTime* c : gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
 								assert(c->activityId==act->id);
 								if(c->activityId==act->id && c->weightPercentage==100.0 && c->active && c->day>=0 && c->hour>=0){
 									count++;
@@ -743,7 +1009,7 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 							if(count!=1)
 								QMessageBox::warning(this, tr("FET warning"), tr("You may have a problem, because FET expected to delete 1 constraint, but will delete %1 constraints").arg(tmptc.size()));
 
-							foreach(TimeConstraint* deltc, tmptc){
+							for(TimeConstraint* deltc : qAsConst(tmptc)){
 								s+=tr("The following constraint will be deleted:")+"\n"+deltc->getDetailedDescription(gt.rules)+"\n";
 								gt.rules.removeTimeConstraint(deltc);
 								//delete deltc; - this is done by rules.remove...
@@ -783,7 +1049,7 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 							tmpsc.clear();
 							int count=0;
 
-							foreach(ConstraintActivityPreferredRoom* c, gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
+							for(ConstraintActivityPreferredRoom* c : gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
 								assert(c->activityId==act->id);
 								if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
 									count++;
@@ -816,7 +1082,7 @@ void TimetableViewStudentsDaysHorizontalForm::lock(bool lockTime, bool lockSpace
 							if(count!=1)
 								QMessageBox::warning(this, tr("FET warning"), tr("You may have a problem, because FET expected to delete 1 constraint, but will delete %1 constraints").arg(tmpsc.size()));
 
-							foreach(SpaceConstraint* delsc, tmpsc){
+							for(SpaceConstraint* delsc : qAsConst(tmpsc)){
 								s+=tr("The following constraint will be deleted:")+"\n"+delsc->getDetailedDescription(gt.rules)+"\n";
 								gt.rules.removeSpaceConstraint(delsc);
 								idsOfLockedSpace.remove(act->id);
@@ -990,6 +1256,10 @@ void TimetableViewStudentsDaysHorizontalForm::help()
 	s+=QCoreApplication::translate("TimetableViewForm", "If a cell is (permanently) locked in time or space, it contains abbreviations to show that: PLT (permanently locked time), LT (locked time), "
 		"PLS (permanently locked space) or LS (locked space).", "Translate the abbreviations also. Make sure the abbreviations in your language are different between themselves "
 		"and the user can differentiate easily between them. These abbreviations may appear also in other places, please use the same abbreviations.");
+	s+="\n\n";
+	s+=QCoreApplication::translate("TimetableViewForm", "There is a combo box in this dialog. You can choose each year, group, and subgroup if you select 'Years',"
+		" each group and subgroup if you select 'Groups', or each subgroup if you select 'Subgroups'.");
+	s+="\n\n";
 
 	LongTextMessageBox::largeInformation(this, tr("FET help"), s);
 }
