@@ -96,7 +96,8 @@ void TimetableViewStudentsTimeHorizontalDelegate::paint(QPainter* painter, const
 	QStyledItemDelegate::paint(painter, option, index);
 
 	//int day=index.column()/gt.rules.nHoursPerDay;
-	int hour=index.column()%gt.rules.nHoursPerDay;
+	//int hour=index.column()%gt.rules.nHoursPerDay;
+	int hour=index.column()%nColumns;
 
 	/*if(day>=0 && day<gt.rules.nDaysPerWeek-1 && hour==gt.rules.nHoursPerDay-1){
 		QPen pen(painter->pen());
@@ -204,18 +205,15 @@ TimetableViewStudentsTimeHorizontalForm::TimetableViewStudentsTimeHorizontalForm
 		return;
 	}*/
 
-	LockUnlock::increaseCommunicationSpinBox();
+	//Commented on 2018-07-20
+	//LockUnlock::increaseCommunicationSpinBox();
 	
 	usedStudentsSet.clear();
 	for(int i=0; i<gt.rules.nInternalActivities; i++){
 		Activity* act=&gt.rules.internalActivitiesList[i];
-		foreach(QString students, act->studentsNames){
+		for(const QString& students : qAsConst(act->studentsNames)){
 			if(!usedStudentsSet.contains(students))
 				usedStudentsSet.insert(students);
-			
-			/*QList<int> list=activitiesForStudentsSet.value(students, QList<int>());
-			list.append(i);
-			activitiesForStudentsSet.insert(students, list);*/
 		}
 	}
 	
@@ -227,52 +225,19 @@ TimetableViewStudentsTimeHorizontalForm::TimetableViewStudentsTimeHorizontalForm
 		it++;
 	}
 	
-	//Students not available constraints
-	/*QSet<QString> studentsSet3;
-	foreach(StudentsYear* year, gt.rules.augmentedYearsList){
-		if(!studentsSet3.contains(year->name)){
-			studentsSet3.insert(year->name);
-		}
-		foreach(StudentsGroup* group, year->groupsList){
-			if(!studentsSet3.contains(group->name)){
-				studentsSet3.insert(group->name);
-			}
-			foreach(StudentsSubgroup* subgroup, group->subgroupsList){
-				if(!studentsSet3.contains(subgroup->name)){
-					studentsSet3.insert(subgroup->name);
-				}
-			}
-		}
-	}
-	
-	//notAvailableHash.clear();
-	for(int i=0; i<gt.rules.nInternalTimeConstraints; i++){
-		TimeConstraint* ctr=gt.rules.internalTimeConstraintsList[i];
-		if(ctr->type==CONSTRAINT_STUDENTS_SET_NOT_AVAILABLE_TIMES){
-			ConstraintStudentsSetNotAvailableTimes* csna=(ConstraintStudentsSetNotAvailableTimes*)ctr;
-			assert(csna->active);
-			if(studentsSet3.contains(csna->students) && !usedStudentsSet.contains(csna->students))
-				usedStudentsSet.insert(csna->students);
-			if(studentsSet3.contains(csna->students)){
-				assert(!notAvailableHash.contains(csna->students));
-				notAvailableHash.insert(csna->students, csna);
-			}
-		}
-	}*/
-	
 	QSet<QString> studentsSet2;
 	usedStudentsList.clear();
-	foreach(StudentsYear* year, gt.rules.augmentedYearsList){
+	for(StudentsYear* year : qAsConst(gt.rules.augmentedYearsList)){
 		if(usedStudentsSet.contains(year->name) && !studentsSet2.contains(year->name)){
 			usedStudentsList.append(year->name);
 			studentsSet2.insert(year->name);
 		}
-		foreach(StudentsGroup* group, year->groupsList){
+		for(StudentsGroup* group : qAsConst(year->groupsList)){
 			if(usedStudentsSet.contains(group->name) && !studentsSet2.contains(group->name)){
 				usedStudentsList.append(group->name);
 				studentsSet2.insert(group->name);
 			}
-			foreach(StudentsSubgroup* subgroup, group->subgroupsList){
+			for(StudentsSubgroup* subgroup : qAsConst(group->subgroupsList)){
 				if(usedStudentsSet.contains(subgroup->name) && !studentsSet2.contains(subgroup->name)){
 					usedStudentsList.append(subgroup->name);
 					studentsSet2.insert(subgroup->name);
@@ -437,6 +402,284 @@ TimetableViewStudentsTimeHorizontalForm::TimetableViewStudentsTimeHorizontalForm
 	updateStudentsTimetableTable();
 }
 
+void TimetableViewStudentsTimeHorizontalForm::newTimetableGenerated()
+//Similar to the constructor
+{
+	//setupUi(this);
+	
+	//closePushButton->setDefault(true);
+	
+	//detailsTextEdit->setReadOnly(true);
+
+	//columnResizeModeInitialized=false;
+
+	/*verticalSplitter->setStretchFactor(0, 20);
+	verticalSplitter->setStretchFactor(1, 1);
+	horizontalSplitter->setStretchFactor(0, 5);
+	horizontalSplitter->setStretchFactor(1, 1);
+
+	studentsTimetableTable->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(studentsTimetableTable, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), this, SLOT(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)));
+	connect(lockTimePushButton, SIGNAL(clicked()), this, SLOT(lockTime()));
+	connect(lockSpacePushButton, SIGNAL(clicked()), this, SLOT(lockSpace()));
+	connect(lockTimeSpacePushButton, SIGNAL(clicked()), this, SLOT(lockTimeSpace()));
+
+	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));*/
+	
+	/*lockRadioButton->setChecked(true);
+	unlockRadioButton->setChecked(false);
+	toggleRadioButton->setChecked(false);
+
+	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
+
+	//restore vertical splitter state
+	QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/vertical-splitter-state")))
+		verticalSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/vertical-splitter-state")).toByteArray());
+
+	//restore horizontal splitter state
+	//QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/horizontal-splitter-state")))
+		horizontalSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/horizontal-splitter-state")).toByteArray());
+
+	if(settings.contains(this->metaObject()->className()+QString("/lock-radio-button")))
+		lockRadioButton->setChecked(settings.value(this->metaObject()->className()+QString("/lock-radio-button")).toBool());
+	if(settings.contains(this->metaObject()->className()+QString("/unlock-radio-button")))
+		unlockRadioButton->setChecked(settings.value(this->metaObject()->className()+QString("/unlock-radio-button")).toBool());
+	if(settings.contains(this->metaObject()->className()+QString("/toggle-radio-button")))
+		toggleRadioButton->setChecked(settings.value(this->metaObject()->className()+QString("/toggle-radio-button")).toBool());*/
+
+///////////just for testing
+	QSet<int> backupLockedTime;
+	QSet<int> backupPermanentlyLockedTime;
+	QSet<int> backupLockedSpace;
+	QSet<int> backupPermanentlyLockedSpace;
+	
+	backupLockedTime=idsOfLockedTime;
+	backupPermanentlyLockedTime=idsOfPermanentlyLockedTime;
+	backupLockedSpace=idsOfLockedSpace;
+	backupPermanentlyLockedSpace=idsOfPermanentlyLockedSpace;
+	
+	//added by Volker Dirr
+	//these 2 lines are not really needed - just to be safer
+	LockUnlock::computeLockedUnlockedActivitiesTimeSpace();
+	
+	assert(backupLockedTime==idsOfLockedTime);
+	assert(backupPermanentlyLockedTime==idsOfPermanentlyLockedTime);
+	assert(backupLockedSpace==idsOfLockedSpace);
+	assert(backupPermanentlyLockedSpace==idsOfPermanentlyLockedSpace);
+///////////
+
+	/*if(gt.rules.nInternalTeachers!=gt.rules.teachersList.count()){
+		QMessageBox::warning(this, tr("FET warning"), tr("Cannot display the timetable, because you added or removed some teachers. Please regenerate the timetable and then view it"));
+		return;
+	}*/
+
+	//DON'T UNCOMMENT THIS CODE -> LEADS TO CRASH IF THERE ARE MORE VIEWS OPENED.
+	//LockUnlock::increaseCommunicationSpinBox();
+	
+	usedStudentsSet.clear();
+	for(int i=0; i<gt.rules.nInternalActivities; i++){
+		Activity* act=&gt.rules.internalActivitiesList[i];
+		for(const QString& students : qAsConst(act->studentsNames)){
+			if(!usedStudentsSet.contains(students))
+				usedStudentsSet.insert(students);
+		}
+	}
+	
+	QHash<QString, QSet<QPair<int, int> > >::const_iterator it=studentsSetNotAvailableDayHour.constBegin();
+	while(it!=studentsSetNotAvailableDayHour.constEnd()){
+		if(!usedStudentsSet.contains(it.key()))
+			usedStudentsSet.insert(it.key());
+			
+		it++;
+	}
+	
+	QSet<QString> studentsSet2;
+	usedStudentsList.clear();
+	for(StudentsYear* year : qAsConst(gt.rules.augmentedYearsList)){
+		if(usedStudentsSet.contains(year->name) && !studentsSet2.contains(year->name)){
+			usedStudentsList.append(year->name);
+			studentsSet2.insert(year->name);
+		}
+		for(StudentsGroup* group : qAsConst(year->groupsList)){
+			if(usedStudentsSet.contains(group->name) && !studentsSet2.contains(group->name)){
+				usedStudentsList.append(group->name);
+				studentsSet2.insert(group->name);
+			}
+			for(StudentsSubgroup* subgroup : qAsConst(group->subgroupsList)){
+				if(usedStudentsSet.contains(subgroup->name) && !studentsSet2.contains(subgroup->name)){
+					usedStudentsList.append(subgroup->name);
+					studentsSet2.insert(subgroup->name);
+				}
+			}
+		}
+	}
+
+	studentsTimetableTable->clear();
+	studentsTimetableTable->setRowCount(usedStudentsList.count());
+	studentsTimetableTable->setColumnCount(gt.rules.nDaysPerWeek*gt.rules.nHoursPerDay);
+	
+	newItemDelegate->nRows=studentsTimetableTable->rowCount();
+	newItemDelegate->nColumns=gt.rules.nHoursPerDay;
+	/*studentsTimetableTable->setItemDelegate(oldItemDelegate);
+	delete newItemDelegate;
+	//oldItemDelegate=studentsTimetableTable->itemDelegate();
+	newItemDelegate=new TimetableViewStudentsTimeHorizontalDelegate(NULL, studentsTimetableTable->rowCount(), gt.rules.nHoursPerDay);
+	studentsTimetableTable->setItemDelegate(newItemDelegate);*/
+	
+	bool min2letters=false;
+	for(int d=0; d<gt.rules.nDaysPerWeek; d++){
+		if(gt.rules.daysOfTheWeek[d].size()>gt.rules.nHoursPerDay){
+			min2letters=true;
+			break;
+		}
+	}
+	for(int d=0; d<gt.rules.nDaysPerWeek; d++){
+		QString dayName=gt.rules.daysOfTheWeek[d];
+		int t=dayName.size();
+		int q=t/gt.rules.nHoursPerDay;
+		int r=t%gt.rules.nHoursPerDay;
+		QStringList list;
+		
+		if(q==0)
+			q=1;
+		
+		for(int i=0; i<gt.rules.nHoursPerDay; i++){
+			if(!min2letters){
+				list.append(dayName.left(1));
+				dayName.remove(0, 1);
+			}
+			else if(i<r || q<=1){
+				assert(q>=1);
+				list.append(dayName.left(q+1));
+				dayName.remove(0, q+1);
+			}
+			else{
+				list.append(dayName.left(q));
+				dayName.remove(0, q);
+			}
+		}
+	
+		for(int h=0; h<gt.rules.nHoursPerDay; h++){
+			QTableWidgetItem* item=new QTableWidgetItem(list.at(h)+"\n"+gt.rules.hoursOfTheDay[h]);
+			item->setToolTip(gt.rules.daysOfTheWeek[d]+"\n"+gt.rules.hoursOfTheDay[h]);
+			studentsTimetableTable->setHorizontalHeaderItem(d*gt.rules.nHoursPerDay+h, item);
+		}
+	}
+	for(int t=0; t<usedStudentsList.count(); t++){
+		QTableWidgetItem* item=new QTableWidgetItem(usedStudentsList.at(t));
+		item->setToolTip(usedStudentsList.at(t));
+		studentsTimetableTable->setVerticalHeaderItem(t, item);
+	}
+
+	for(int t=0; t<usedStudentsList.count(); t++){
+		for(int d=0; d<gt.rules.nDaysPerWeek; d++){
+			for(int h=0; h<gt.rules.nHoursPerDay; h++){
+				QTableWidgetItem* item= new QTableWidgetItem();
+				item->setTextAlignment(Qt::AlignCenter);
+				item->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEnabled);
+
+				studentsTimetableTable->setItem(t, d*gt.rules.nHoursPerDay+h, item);
+			}
+		}
+	}
+	
+	//resize columns
+	//if(!columnResizeModeInitialized){
+//	teachersTimetableTable->horizontalHeader()->setMinimumSectionSize(teachersTimetableTable->horizontalHeader()->defaultSectionSize());
+	//	columnResizeModeInitialized=true;
+	
+	/*initialRecommendedHeight=studentsTimetableTable->verticalHeader()->sectionSizeHint(0);
+	
+	int h;
+	int w;
+
+	if(settings.contains(this->metaObject()->className()+QString("/vertical-header-size"))){
+		h=settings.value(this->metaObject()->className()+QString("/vertical-header-size")).toInt();
+		if(h==0)
+			h=MINIMUM_HEIGHT_SPIN_BOX_VALUE;
+	}
+	else{
+		h=MINIMUM_HEIGHT_SPIN_BOX_VALUE;
+	}
+//	if(h==0)
+//		h=initialRecommendedHeight;
+
+	if(settings.contains(this->metaObject()->className()+QString("/horizontal-header-size"))){
+		w=settings.value(this->metaObject()->className()+QString("/horizontal-header-size")).toInt();
+		if(w==0)
+			w=MINIMUM_WIDTH_SPIN_BOX_VALUE;
+	}
+	else{
+		w=MINIMUM_WIDTH_SPIN_BOX_VALUE;
+	}
+//	if(w==0)
+//		w=2*initialRecommendedHeight;
+		
+	widthSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
+	widthSpinBox->setMinimum(MINIMUM_WIDTH_SPIN_BOX_VALUE);
+#if QT_VERSION >= 0x050200
+	widthSpinBox->setMaximum(studentsTimetableTable->verticalHeader()->maximumSectionSize());
+#else
+	widthSpinBox->setMaximum(maxScreenWidth(this));
+#endif
+	widthSpinBox->setValue(w);
+	widthSpinBox->setSpecialValueText(tr("Automatic"));
+	
+	heightSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
+	heightSpinBox->setMinimum(MINIMUM_HEIGHT_SPIN_BOX_VALUE);
+#if QT_VERSION >= 0x050200
+	heightSpinBox->setMaximum(studentsTimetableTable->verticalHeader()->maximumSectionSize());
+#else
+	heightSpinBox->setMaximum(maxScreenWidth(this));
+#endif
+	heightSpinBox->setValue(h);
+	heightSpinBox->setSpecialValueText(tr("Automatic"));
+	
+	widthSpinBoxValueChanged();
+	heightSpinBoxValueChanged();
+	
+	connect(widthSpinBox, SIGNAL(valueChanged(int)), this, SLOT(widthSpinBoxValueChanged()));
+	connect(heightSpinBox, SIGNAL(valueChanged(int)), this, SLOT(heightSpinBoxValueChanged()));
+	
+//	teachersTimetableTable->verticalHeader()->setDefaultSectionSize(h);
+//	teachersTimetableTable->horizontalHeader()->setDefaultSectionSize(w);
+
+#if QT_VERSION >= 0x050000
+	studentsTimetableTable->verticalHeader()->setSectionResizeMode(QHeaderView::Interactive);
+	studentsTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
+#else
+	studentsTimetableTable->verticalHeader()->setResizeMode(QHeaderView::Interactive);
+	studentsTimetableTable->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+#endif
+	//}
+	////////////////
+	
+	subjectsCheckBox->setChecked(true);
+	teachersCheckBox->setChecked(false);
+	
+	if(settings.contains(this->metaObject()->className()+QString("/subjects-check-box-state"))){
+		bool state=settings.value(this->metaObject()->className()+QString("/subjects-check-box-state")).toBool();
+		subjectsCheckBox->setChecked(state);
+	}
+	if(settings.contains(this->metaObject()->className()+QString("/teachers-check-box-state"))){
+		bool state=settings.value(this->metaObject()->className()+QString("/teachers-check-box-state")).toBool();
+		teachersCheckBox->setChecked(state);
+	}
+	
+	connect(subjectsCheckBox, SIGNAL(toggled(bool)), this, SLOT(updateStudentsTimetableTable()));
+	connect(teachersCheckBox, SIGNAL(toggled(bool)), this, SLOT(updateStudentsTimetableTable()));*/
+	
+	//added by Volker Dirr
+	//connect(&communicationSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateStudentsTimetableTable()));
+	
+	updateStudentsTimetableTable();
+}
+
 TimetableViewStudentsTimeHorizontalForm::~TimetableViewStudentsTimeHorizontalForm()
 {
 	saveFETDialogGeometry(this);
@@ -859,6 +1102,12 @@ void TimetableViewStudentsTimeHorizontalForm::detailActivity(QTableWidgetItem* i
 			if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
 				s+="\n";
 				s+=tr("Room: %1").arg(gt.rules.internalRoomsList[r]->name);
+				if(gt.rules.internalRoomsList[r]->building!=""){
+					s+="\n";
+					s+=tr("Building=%1").arg(gt.rules.internalRoomsList[r]->building);
+				}
+				s+="\n";
+				s+=tr("Capacity=%1").arg(gt.rules.internalRoomsList[r]->capacity);
 			}
 			//added by Volker Dirr (start)
 			QString descr="";
@@ -1048,7 +1297,7 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 				QList<TimeConstraint*> tmptc;
 				int count=0;
 
-				foreach(ConstraintActivityPreferredStartingTime* c, gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
+				for(ConstraintActivityPreferredStartingTime* c : gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
 					assert(c->activityId==act->id);
 					if(c->activityId==act->id && c->weightPercentage==100.0 && c->active && c->day>=0 && c->hour>=0){
 						count++;
@@ -1102,7 +1351,7 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 					if(count>=2)
 						QMessageBox::warning(this, tr("FET warning"), tr("You may have a problem, because FET expected to delete 1 constraint, but will delete %1 constraints").arg(tmptc.size()));
 
-					foreach(TimeConstraint* deltc, tmptc){
+					for(TimeConstraint* deltc : qAsConst(tmptc)){
 						s+=tr("The following constraint will be deleted:")+"\n"+deltc->getDetailedDescription(gt.rules)+"\n";
 						gt.rules.removeTimeConstraint(deltc);
 						idsOfLockedTime.remove(act->id);
@@ -1130,7 +1379,7 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 				QList<SpaceConstraint*> tmpsc;
 				int count=0;
 
-				foreach(ConstraintActivityPreferredRoom* c, gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
+				for(ConstraintActivityPreferredRoom* c : gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
 					assert(c->activityId==act->id);
 
 					if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
@@ -1187,7 +1436,7 @@ void TimetableViewStudentsTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 					if(count>=2)
 						QMessageBox::warning(this, tr("FET warning"), tr("You may have a problem, because FET expected to delete 1 constraint, but will delete %1 constraints").arg(tmpsc.size()));
 
-					foreach(SpaceConstraint* delsc, tmpsc){
+					for(SpaceConstraint* delsc : qAsConst(tmpsc)){
 						s+=tr("The following constraint will be deleted:")+"\n"+delsc->getDetailedDescription(gt.rules)+"\n";
 						gt.rules.removeSpaceConstraint(delsc);
 						idsOfLockedSpace.remove(act->id);
