@@ -89,7 +89,8 @@ void TimetableViewTeachersTimeHorizontalDelegate::paint(QPainter* painter, const
 	QStyledItemDelegate::paint(painter, option, index);
 
 	//int day=index.column()/gt.rules.nHoursPerDay;
-	int hour=index.column()%gt.rules.nHoursPerDay;
+	//int hour=index.column()%gt.rules.nHoursPerDay;
+	int hour=index.column()%nColumns;
 
 	/*if(day>=0 && day<gt.rules.nDaysPerWeek-1 && hour==gt.rules.nHoursPerDay-1){
 		QPen pen(painter->pen());
@@ -205,7 +206,8 @@ TimetableViewTeachersTimeHorizontalForm::TimetableViewTeachersTimeHorizontalForm
 		return;
 	}
 
-	LockUnlock::increaseCommunicationSpinBox();
+	//Commented on 2018-07-20
+	//LockUnlock::increaseCommunicationSpinBox();
 	
 	teachersTimetableTable->setRowCount(gt.rules.nInternalTeachers);
 	teachersTimetableTable->setColumnCount(gt.rules.nDaysPerWeek*gt.rules.nHoursPerDay);
@@ -364,6 +366,245 @@ TimetableViewTeachersTimeHorizontalForm::TimetableViewTeachersTimeHorizontalForm
 	updateTeachersTimetableTable();
 }
 
+void TimetableViewTeachersTimeHorizontalForm::newTimetableGenerated()
+{
+	//setupUi(this);
+	
+	//closePushButton->setDefault(true);
+	
+	//detailsTextEdit->setReadOnly(true);
+
+	//columnResizeModeInitialized=false;
+
+	/*verticalSplitter->setStretchFactor(0, 20);
+	verticalSplitter->setStretchFactor(1, 1);
+	horizontalSplitter->setStretchFactor(0, 5);
+	horizontalSplitter->setStretchFactor(1, 1);
+
+	teachersTimetableTable->setSelectionMode(QAbstractItemView::ExtendedSelection);
+	
+	connect(closePushButton, SIGNAL(clicked()), this, SLOT(close()));
+	connect(teachersTimetableTable, SIGNAL(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)), this, SLOT(currentItemChanged(QTableWidgetItem*, QTableWidgetItem*)));
+	connect(lockTimePushButton, SIGNAL(clicked()), this, SLOT(lockTime()));
+	connect(lockSpacePushButton, SIGNAL(clicked()), this, SLOT(lockSpace()));
+	connect(lockTimeSpacePushButton, SIGNAL(clicked()), this, SLOT(lockTimeSpace()));
+
+	connect(helpPushButton, SIGNAL(clicked()), this, SLOT(help()));*/
+	
+	/*lockRadioButton->setChecked(true);
+	unlockRadioButton->setChecked(false);
+	toggleRadioButton->setChecked(false);
+
+	centerWidgetOnScreen(this);
+	restoreFETDialogGeometry(this);
+
+	//restore vertical splitter state
+	QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/vertical-splitter-state")))
+		verticalSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/vertical-splitter-state")).toByteArray());
+
+	//restore horizontal splitter state
+	//QSettings settings(COMPANY, PROGRAM);
+	if(settings.contains(this->metaObject()->className()+QString("/horizontal-splitter-state")))
+		horizontalSplitter->restoreState(settings.value(this->metaObject()->className()+QString("/horizontal-splitter-state")).toByteArray());
+
+	if(settings.contains(this->metaObject()->className()+QString("/lock-radio-button")))
+		lockRadioButton->setChecked(settings.value(this->metaObject()->className()+QString("/lock-radio-button")).toBool());
+	if(settings.contains(this->metaObject()->className()+QString("/unlock-radio-button")))
+		unlockRadioButton->setChecked(settings.value(this->metaObject()->className()+QString("/unlock-radio-button")).toBool());
+	if(settings.contains(this->metaObject()->className()+QString("/toggle-radio-button")))
+		toggleRadioButton->setChecked(settings.value(this->metaObject()->className()+QString("/toggle-radio-button")).toBool());*/
+
+///////////just for testing
+	QSet<int> backupLockedTime;
+	QSet<int> backupPermanentlyLockedTime;
+	QSet<int> backupLockedSpace;
+	QSet<int> backupPermanentlyLockedSpace;
+	
+	backupLockedTime=idsOfLockedTime;
+	backupPermanentlyLockedTime=idsOfPermanentlyLockedTime;
+	backupLockedSpace=idsOfLockedSpace;
+	backupPermanentlyLockedSpace=idsOfPermanentlyLockedSpace;
+	
+	//added by Volker Dirr
+	//these 2 lines are not really needed - just to be safer
+	LockUnlock::computeLockedUnlockedActivitiesTimeSpace();
+	
+	assert(backupLockedTime==idsOfLockedTime);
+	assert(backupPermanentlyLockedTime==idsOfPermanentlyLockedTime);
+	assert(backupLockedSpace==idsOfLockedSpace);
+	assert(backupPermanentlyLockedSpace==idsOfPermanentlyLockedSpace);
+///////////
+
+	if(gt.rules.nInternalTeachers!=gt.rules.teachersList.count()){
+		assert(0); //should be taken care of by Rules - teachers_schedule_ready is false in the Rules if adding or removing teachers.
+	}
+
+	//DON'T UNCOMMENT THIS CODE -> LEADS TO CRASH IF THERE ARE MORE VIEWS OPENED.
+	//LockUnlock::increaseCommunicationSpinBox();
+	
+	teachersTimetableTable->clear();
+	teachersTimetableTable->setRowCount(gt.rules.nInternalTeachers);
+	teachersTimetableTable->setColumnCount(gt.rules.nDaysPerWeek*gt.rules.nHoursPerDay);
+	
+	newItemDelegate->nRows=teachersTimetableTable->rowCount();
+	newItemDelegate->nColumns=gt.rules.nHoursPerDay;
+	/*teachersTimetableTable->setItemDelegate(oldItemDelegate);
+	delete newItemDelegate;
+	//oldItemDelegate=teachersTimetableTable->itemDelegate();
+	newItemDelegate=new TimetableViewTeachersTimeHorizontalDelegate(NULL, teachersTimetableTable->rowCount(), gt.rules.nHoursPerDay);
+	teachersTimetableTable->setItemDelegate(newItemDelegate);*/
+	
+	bool min2letters=false;
+	for(int d=0; d<gt.rules.nDaysPerWeek; d++){
+		if(gt.rules.daysOfTheWeek[d].size()>gt.rules.nHoursPerDay){
+			min2letters=true;
+			break;
+		}
+	}
+	//QMessageBox::information(this, "", QString::number(min2letters));
+	for(int d=0; d<gt.rules.nDaysPerWeek; d++){
+		QString dayName=gt.rules.daysOfTheWeek[d];
+		int t=dayName.size();
+		int q=t/gt.rules.nHoursPerDay;
+		int r=t%gt.rules.nHoursPerDay;
+		QStringList list;
+		
+		if(q==0)
+			q=1;
+		
+		for(int i=0; i<gt.rules.nHoursPerDay; i++){
+			if(!min2letters){
+				list.append(dayName.left(1));
+				dayName.remove(0, 1);
+			}
+			else if(i<r || q<=1){
+				assert(q>=1);
+				list.append(dayName.left(q+1));
+				dayName.remove(0, q+1);
+			}
+			else{
+				list.append(dayName.left(q));
+				dayName.remove(0, q);
+			}
+		}
+	
+		for(int h=0; h<gt.rules.nHoursPerDay; h++){
+			QTableWidgetItem* item=new QTableWidgetItem(list.at(h)+"\n"+gt.rules.hoursOfTheDay[h]);
+			item->setToolTip(gt.rules.daysOfTheWeek[d]+"\n"+gt.rules.hoursOfTheDay[h]);
+			teachersTimetableTable->setHorizontalHeaderItem(d*gt.rules.nHoursPerDay+h, item);
+		}
+	}
+	for(int t=0; t<gt.rules.nInternalTeachers; t++){
+		QTableWidgetItem* item=new QTableWidgetItem(gt.rules.internalTeachersList[t]->name);
+		item->setToolTip(gt.rules.internalTeachersList[t]->name);
+		teachersTimetableTable->setVerticalHeaderItem(t, item);
+	}
+
+	for(int t=0; t<gt.rules.nInternalTeachers; t++){
+		for(int d=0; d<gt.rules.nDaysPerWeek; d++){
+			for(int h=0; h<gt.rules.nHoursPerDay; h++){
+				QTableWidgetItem* item= new QTableWidgetItem();
+				item->setTextAlignment(Qt::AlignCenter);
+				item->setFlags(Qt::ItemIsSelectable|Qt::ItemIsEnabled);
+
+				teachersTimetableTable->setItem(t, d*gt.rules.nHoursPerDay+h, item);
+			}
+		}
+	}
+	
+	//resize columns
+	//if(!columnResizeModeInitialized){
+//	teachersTimetableTable->horizontalHeader()->setMinimumSectionSize(teachersTimetableTable->horizontalHeader()->defaultSectionSize());
+	//	columnResizeModeInitialized=true;
+	
+	/*initialRecommendedHeight=teachersTimetableTable->verticalHeader()->sectionSizeHint(0);
+	
+	int h;
+	int w;
+
+	if(settings.contains(this->metaObject()->className()+QString("/vertical-header-size"))){
+		h=settings.value(this->metaObject()->className()+QString("/vertical-header-size")).toInt();
+		if(h==0)
+			h=MINIMUM_HEIGHT_SPIN_BOX_VALUE;
+	}
+	else{
+		h=MINIMUM_HEIGHT_SPIN_BOX_VALUE;
+	}
+//	if(h==0)
+//		h=initialRecommendedHeight;
+
+	if(settings.contains(this->metaObject()->className()+QString("/horizontal-header-size"))){
+		w=settings.value(this->metaObject()->className()+QString("/horizontal-header-size")).toInt();
+		if(w==0)
+			w=MINIMUM_WIDTH_SPIN_BOX_VALUE;
+	}
+	else{
+		w=MINIMUM_WIDTH_SPIN_BOX_VALUE;
+	}
+//	if(w==0)
+//		w=2*initialRecommendedHeight;
+		
+	widthSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
+	widthSpinBox->setMinimum(MINIMUM_WIDTH_SPIN_BOX_VALUE);
+#if QT_VERSION >= 0x050200
+	widthSpinBox->setMaximum(teachersTimetableTable->verticalHeader()->maximumSectionSize());
+#else
+	widthSpinBox->setMaximum(maxScreenWidth(this));
+#endif
+	widthSpinBox->setValue(w);
+	widthSpinBox->setSpecialValueText(tr("Automatic"));
+	
+	heightSpinBox->setSuffix(QString(" ")+tr("px", "Abbreviation for pixels"));
+	heightSpinBox->setMinimum(MINIMUM_HEIGHT_SPIN_BOX_VALUE);
+#if QT_VERSION >= 0x050200
+	heightSpinBox->setMaximum(teachersTimetableTable->verticalHeader()->maximumSectionSize());
+#else
+	heightSpinBox->setMaximum(maxScreenWidth(this));
+#endif
+	heightSpinBox->setValue(h);
+	heightSpinBox->setSpecialValueText(tr("Automatic"));
+	
+	widthSpinBoxValueChanged();
+	heightSpinBoxValueChanged();
+	
+	connect(widthSpinBox, SIGNAL(valueChanged(int)), this, SLOT(widthSpinBoxValueChanged()));
+	connect(heightSpinBox, SIGNAL(valueChanged(int)), this, SLOT(heightSpinBoxValueChanged()));
+	
+//	teachersTimetableTable->verticalHeader()->setDefaultSectionSize(h);
+//	teachersTimetableTable->horizontalHeader()->setDefaultSectionSize(w);
+
+#if QT_VERSION >= 0x050000
+	teachersTimetableTable->verticalHeader()->setSectionResizeMode(QHeaderView::Interactive);
+	teachersTimetableTable->horizontalHeader()->setSectionResizeMode(QHeaderView::Interactive);
+#else
+	teachersTimetableTable->verticalHeader()->setResizeMode(QHeaderView::Interactive);
+	teachersTimetableTable->horizontalHeader()->setResizeMode(QHeaderView::Interactive);
+#endif
+	//}
+	////////////////
+	
+	subjectsCheckBox->setChecked(true);
+	studentsCheckBox->setChecked(true);
+	
+	if(settings.contains(this->metaObject()->className()+QString("/subjects-check-box-state"))){
+		bool state=settings.value(this->metaObject()->className()+QString("/subjects-check-box-state")).toBool();
+		subjectsCheckBox->setChecked(state);
+	}
+	if(settings.contains(this->metaObject()->className()+QString("/students-check-box-state"))){
+		bool state=settings.value(this->metaObject()->className()+QString("/students-check-box-state")).toBool();
+		studentsCheckBox->setChecked(state);
+	}
+	
+	connect(subjectsCheckBox, SIGNAL(toggled(bool)), this, SLOT(updateTeachersTimetableTable()));
+	connect(studentsCheckBox, SIGNAL(toggled(bool)), this, SLOT(updateTeachersTimetableTable()));*/
+	
+	//added by Volker Dirr
+	//connect(&communicationSpinBox, SIGNAL(valueChanged(int)), this, SLOT(updateTeachersTimetableTable()));
+	
+	updateTeachersTimetableTable();
+}
+
 TimetableViewTeachersTimeHorizontalForm::~TimetableViewTeachersTimeHorizontalForm()
 {
 	saveFETDialogGeometry(this);
@@ -674,6 +915,12 @@ void TimetableViewTeachersTimeHorizontalForm::detailActivity(QTableWidgetItem* i
 				if(r!=UNALLOCATED_SPACE && r!=UNSPECIFIED_ROOM){
 					s+="\n";
 					s+=tr("Room: %1").arg(gt.rules.internalRoomsList[r]->name);
+					if(gt.rules.internalRoomsList[r]->building!=""){
+						s+="\n";
+						s+=tr("Building=%1").arg(gt.rules.internalRoomsList[r]->building);
+					}
+					s+="\n";
+					s+=tr("Capacity=%1").arg(gt.rules.internalRoomsList[r]->capacity);
 				}
 				//added by Volker Dirr (start)
 				QString descr="";
@@ -820,7 +1067,7 @@ void TimetableViewTeachersTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 				QList<TimeConstraint*> tmptc;
 				int count=0;
 
-				foreach(ConstraintActivityPreferredStartingTime* c, gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
+				for(ConstraintActivityPreferredStartingTime* c : gt.rules.apstHash.value(act->id, QSet<ConstraintActivityPreferredStartingTime*>())){
 					assert(c->activityId==act->id);
 					if(c->activityId==act->id && c->weightPercentage==100.0 && c->active && c->day>=0 && c->hour>=0){
 						count++;
@@ -874,7 +1121,7 @@ void TimetableViewTeachersTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 					if(count>=2)
 						QMessageBox::warning(this, tr("FET warning"), tr("You may have a problem, because FET expected to delete 1 constraint, but will delete %1 constraints").arg(tmptc.size()));
 
-					foreach(TimeConstraint* deltc, tmptc){
+					for(TimeConstraint* deltc : qAsConst(tmptc)){
 						s+=tr("The following constraint will be deleted:")+"\n"+deltc->getDetailedDescription(gt.rules)+"\n";
 						gt.rules.removeTimeConstraint(deltc);
 						idsOfLockedTime.remove(act->id);
@@ -902,7 +1149,7 @@ void TimetableViewTeachersTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 				QList<SpaceConstraint*> tmpsc;
 				int count=0;
 
-				foreach(ConstraintActivityPreferredRoom* c, gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
+				for(ConstraintActivityPreferredRoom* c : gt.rules.aprHash.value(act->id, QSet<ConstraintActivityPreferredRoom*>())){
 					assert(c->activityId==act->id);
 
 					if(c->activityId==act->id && c->weightPercentage==100.0 && c->active){
@@ -959,7 +1206,7 @@ void TimetableViewTeachersTimeHorizontalForm::lock(bool lockTime, bool lockSpace
 					if(count>=2)
 						QMessageBox::warning(this, tr("FET warning"), tr("You may have a problem, because FET expected to delete 1 constraint, but will delete %1 constraints").arg(tmpsc.size()));
 
-					foreach(SpaceConstraint* delsc, tmpsc){
+					for(SpaceConstraint* delsc : qAsConst(tmpsc)){
 						s+=tr("The following constraint will be deleted:")+"\n"+delsc->getDetailedDescription(gt.rules)+"\n";
 						gt.rules.removeSpaceConstraint(delsc);
 						idsOfLockedSpace.remove(act->id);
